@@ -16,8 +16,7 @@ from deepdiff.delta import (
     INVALID_ACTION_WHEN_CALLING_SIMPLE_DELETE_ELEM, INDEXES_NOT_FOUND_WHEN_IGNORE_ORDER,
     FAIL_TO_REMOVE_ITEM_IGNORE_ORDER_MSG, UNABLE_TO_GET_PATH_MSG, NOT_VALID_NUMPY_TYPE)
 from deepdiff.serialization import (
-    DELTA_IGNORE_ORDER_NEEDS_REPETITION_REPORT, DELTA_ERROR_WHEN_GROUP_BY,
-    json_dumps, json_loads,
+    DELTA_IGNORE_ORDER_NEEDS_REPETITION_REPORT, DELTA_ERROR_WHEN_GROUP_BY
 )
 
 from tests import PicklableClass, parameterize_cases, CustomClass, CustomClass2
@@ -25,35 +24,6 @@ from tests import PicklableClass, parameterize_cases, CustomClass, CustomClass2
 
 class TestBasicsOfDelta:
 
-    def test_from_null_delta_json(self):
-        t1 = None
-        t2 = [1, 2, 3, 5]
-        diff = DeepDiff(t1, t2)
-        delta = Delta(diff, serializer=json_dumps)
-        dump = delta.dumps()
-        delta2 = Delta(dump, deserializer=json_loads)
-        assert delta2 + t1 == t2
-        assert t1 + delta2 == t2
-
-    def test_to_null_delta1_json(self):
-        t1 = 1
-        t2 = None
-        diff = DeepDiff(t1, t2)
-        delta = Delta(diff, serializer=json_dumps)
-        dump = delta.dumps()
-        delta2 = Delta(dump, deserializer=json_loads)
-        assert delta2 + t1 == t2
-        assert t1 + delta2 == t2
-
-    def test_to_null_delta2_json(self):
-        t1 = [1, 2, 3, 5]
-        t2 = None
-        diff = DeepDiff(t1, t2)
-        delta = Delta(diff)
-
-        assert delta + t1 == t2
-        assert t1 + delta == t2
-
     def test_list_difference_add_delta(self):
         t1 = [1, 2]
         t2 = [1, 2, 3, 5]
@@ -84,35 +54,35 @@ class TestBasicsOfDelta:
 
         assert t1 + delta1 + delta2 == t3
 
-    def test_delta_dump_and_read1(self, tmp_path):
+    def test_delta_dump_and_read1(self):
         t1 = [1, 2]
         t2 = [1, 2, 3, 5]
         diff = DeepDiff(t1, t2)
-        path = os.path.join(tmp_path, 'delta_test.delta')
+        path = '/tmp/delta_test.delta'
         with open(path, 'wb') as the_file:
             Delta(diff).dump(the_file)
         delta = Delta(delta_path=path)
         os.remove(path)
         assert delta + t1 == t2
 
-    def test_delta_dump_and_read2(self, tmp_path):
+    def test_delta_dump_and_read2(self):
         t1 = [1, 2]
         t2 = [1, 2, 3, 5]
         diff = DeepDiff(t1, t2)
         delta_content = Delta(diff).dumps()
-        path = os.path.join('tmp_path, delta_test2.delta')
+        path = '/tmp/delta_test2.delta'
         with open(path, 'wb') as the_file:
             the_file.write(delta_content)
         delta = Delta(delta_path=path)
         os.remove(path)
         assert delta + t1 == t2
 
-    def test_delta_dump_and_read3(self, tmp_path):
+    def test_delta_dump_and_read3(self):
         t1 = [1, 2]
         t2 = [1, 2, 3, 5]
         diff = DeepDiff(t1, t2)
         delta_content = Delta(diff).dumps()
-        path = os.path.join('tmp_path, delta_test2.delta')
+        path = '/tmp/delta_test2.delta'
         with open(path, 'wb') as the_file:
             the_file.write(delta_content)
         with pytest.raises(ValueError) as excinfo:
@@ -634,28 +604,21 @@ DELTA_CASES = {
         'to_delta_kwargs': {},
         'expected_delta_dict': {'iterable_item_removed': {'root[9]': 'a', 'root[10]': 'b', 'root[11]': 'c'}}
     },
-    'delta_case19_value_removed_from_the_middle_of_list': {
-        't1': [0, 1, 2, 3, 4, 5, 6, 7, 8, 'a', 'b', 'c'],
-        't2': [0, 1, 2, 3, 5, 6, 7, 8, 'a', 'b', 'c'],
-        'deepdiff_kwargs': {},
-        'to_delta_kwargs': {'directed': True},
-        'expected_delta_dict': {'iterable_item_removed': {'root[4]': 4}}
-    },
 }
 
 
-DELTA_CASES_PARAMS = parameterize_cases('test_name, t1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict', DELTA_CASES)
+DELTA_CASES_PARAMS = parameterize_cases('t1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict', DELTA_CASES)
 
 
 class TestDelta:
 
     @pytest.mark.parametrize(**DELTA_CASES_PARAMS)
-    def test_delta_cases(self, test_name, t1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict):
+    def test_delta_cases(self, t1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict):
         diff = DeepDiff(t1, t2, **deepdiff_kwargs)
         delta_dict = diff._to_delta_dict(**to_delta_kwargs)
-        assert expected_delta_dict == delta_dict, f"test_delta_cases {test_name} failed."
+        assert expected_delta_dict == delta_dict
         delta = Delta(diff, verify_symmetry=False, raise_errors=True)
-        assert t1 + delta == t2, f"test_delta_cases {test_name} failed."
+        assert t1 + delta == t2
 
 
 DELTA_IGNORE_ORDER_CASES = {
@@ -938,15 +901,15 @@ DELTA_IGNORE_ORDER_CASES = {
 }
 
 DELTA_IGNORE_ORDER_CASES_PARAMS = parameterize_cases(
-    'test_name, t1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict, expected_t1_plus_delta', DELTA_IGNORE_ORDER_CASES)
+    't1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict, expected_t1_plus_delta', DELTA_IGNORE_ORDER_CASES)
 
 
 class TestIgnoreOrderDelta:
 
     @pytest.mark.parametrize(**DELTA_IGNORE_ORDER_CASES_PARAMS)
     def test_ignore_order_delta_cases(
-            self, test_name, t1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict, expected_t1_plus_delta, request):
-        # test_name = request.node.callspec.id
+            self, t1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict, expected_t1_plus_delta, request):
+        test_name = request.node.callspec.id
         diff = DeepDiff(t1, t2, **deepdiff_kwargs)
         delta_dict = diff._to_delta_dict(**to_delta_kwargs)
         assert expected_delta_dict == delta_dict, f"test_ignore_order_delta_cases {test_name} failed"
@@ -1101,31 +1064,31 @@ DELTA_NUMPY_TEST_CASES = {
 
 
 DELTA_NUMPY_TEST_PARAMS = parameterize_cases(
-    'test_name, t1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict, expected_result', DELTA_NUMPY_TEST_CASES)
+    't1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict, expected_result', DELTA_NUMPY_TEST_CASES)
 
 
 class TestNumpyDelta:
 
     @pytest.mark.parametrize(**DELTA_NUMPY_TEST_PARAMS)
-    def test_numpy_delta_cases(self, test_name, t1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict, expected_result):
+    def test_numpy_delta_cases(self, t1, t2, deepdiff_kwargs, to_delta_kwargs, expected_delta_dict, expected_result):
         diff = DeepDiff(t1, t2, **deepdiff_kwargs)
         delta_dict = diff._to_delta_dict(**to_delta_kwargs)
         if expected_delta_dict:
-            assert expected_delta_dict == delta_dict, f"test_numpy_delta_cases {test_name} failed."
+            assert expected_delta_dict == delta_dict
         delta = Delta(diff, verify_symmetry=False, raise_errors=True)
         if expected_result == 't2':
             result = delta + t1
-            assert np.array_equal(result, t2), f"test_numpy_delta_cases {test_name} failed."
+            assert np.array_equal(result, t2)
         elif expected_result == 't2_via_deepdiff':
             result = delta + t1
             diff = DeepDiff(result, t2, ignore_order=True, report_repetition=True)
-            assert not diff, f"test_numpy_delta_cases {test_name} failed."
+            assert not diff
         elif expected_result is DeltaNumpyOperatorOverrideError:
             with pytest.raises(DeltaNumpyOperatorOverrideError):
-                t1 + delta
+                assert t1 + delta
         else:
             result = delta + t1
-            assert np.array_equal(result, expected_result), f"test_numpy_delta_cases {test_name} failed."
+            assert np.array_equal(result, expected_result)
 
     def test_invalid_numpy_type(self):
 
@@ -1182,7 +1145,6 @@ class TestDeltaOther:
             'ignore_type_in_groups': [],
             'report_repetition': True,
             'exclude_paths': None,
-            'include_paths': None,
             'exclude_regex_paths': None,
             'exclude_types': None,
             'exclude_types_tuple': None,
@@ -1517,27 +1479,11 @@ class TestDeltaCompareFunc:
         t2 = [{'id': 3, 'val': 3}, {'id': 2, 'val': 2}, {'id': 1, 'val': 3}]
         ddiff = DeepDiff(t1, t2, iterable_compare_func=self.compare_func, verbose_level=2)
         expected = {
-            "iterable_item_removed": {
-                "root[2]": {
-                    "id": 1,
-                    "val": 3
-                }
-            },
-            "iterable_item_moved": {
-                "root[0]": {
-                    "new_path": "root[2]",
-                    "value": {
-                        "id": 1,
-                        "val": 3
-                    }
-                },
-                "root[3]": {
-                    "new_path": "root[0]",
-                    "value": {
-                        "id": 3,
-                        "val": 3
-                    }
-                }
+            'values_changed': {"root[2]['val']": {'new_value': 3, 'old_value': 1}},
+            'iterable_item_removed': {'root[2]': {'id': 1, 'val': 3}},
+            'iterable_item_moved': {
+                'root[0]': {'new_path': 'root[2]', 'value': {'id': 1, 'val': 3}},
+                'root[3]': {'new_path': 'root[0]', 'value': {'id': 3, 'val': 3}}
             }
         }
         assert expected == ddiff
@@ -1550,27 +1496,11 @@ class TestDeltaCompareFunc:
         t2 = [{'id': 1, 'val': 1}, {'id': 2, 'val': 2}, {'id': 1, 'val': 3}, {'id': 3, 'val': 3}]
         ddiff = DeepDiff(t1, t2, iterable_compare_func=self.compare_func, verbose_level=2)
         expected = {
-            'iterable_item_added': {
-                'root[2]': {
-                    'id': 1,
-                    'val': 3
-                }
-            },
+            'values_changed': {"root[0]['val']": {'new_value': 1, 'old_value': 3}},
+            'iterable_item_added': {'root[2]': {'id': 1, 'val': 3}},
             'iterable_item_moved': {
-                'root[0]': {
-                    'new_path': 'root[3]',
-                    'value': {
-                        'id': 3,
-                        'val': 3
-                    }
-                },
-                'root[2]': {
-                    'new_path': 'root[0]',
-                    'value': {
-                        'id': 1,
-                        'val': 1
-                    }
-                }
+                'root[2]': {'new_path': 'root[0]', 'value': {'id': 1, 'val': 1}},
+                'root[0]': {'new_path': 'root[3]', 'value': {'id': 3, 'val': 3}}
             }
         }
         assert expected == ddiff
